.. include:: links.inc

Introduction
============

These pages describe a git_ and github_ workflow for the `Iris`_
project.

This is not a comprehensive git reference, it's just a workflow for our
own project.  It's tailored to the github hosting service. You may well
find better or quicker ways of getting stuff done with git, but these
should get you started.

.. tip:: Please see the official `git documentation`_ for a complete list of
         git **commands** and **cheat sheets**.